<?php

class ReplaceTest extends PHPUnit_Framework_TestCase
{
	public function testReplaceWithToolbarId()
	{
		$surly = new Surly('AA00150');
		
		$text = '
			<a href="http://www.some.com/thing?test=5&a=5">link</a>
			<a href="https://www.some.com/thing?test=5&a=5">link</a>
			<a href="http://www.some.com/thing/">link</a>
			<a href="https://www.some.com/thing/">link</a>
			<a href="http://www.some.com/thing?test=5&a=5">http://www.some.com/thing?test=5&a=5</a>
			<a href="https://www.some.com/thing?test=5&a=5">https://www.some.com/thing?test=5&a=5</a>
			<a href="http://www.some.com/thing/">http://www.some.com/thing/</a>
			<a href="https://www.some.com/thing/">https://www.some.com/thing/</a>
			';
		
		$expected = '
			<a href="http://sur.ly/o/some.com/thing%3Ftest%3D5%26a%3D5/AA00150">link</a>
			<a href="https://sur.ly/o/some.com/thing%3Ftest%3D5%26a%3D5/AA00150">link</a>
			<a href="http://sur.ly/o/some.com/thing%2F/AA00150">link</a>
			<a href="https://sur.ly/o/some.com/thing%2F/AA00150">link</a>
			<a href="http://sur.ly/o/some.com/thing%3Ftest%3D5%26a%3D5/AA00150">http://www.some.com/thing?test=5&a=5</a>
			<a href="https://sur.ly/o/some.com/thing%3Ftest%3D5%26a%3D5/AA00150">https://www.some.com/thing?test=5&a=5</a>
			<a href="http://sur.ly/o/some.com/thing%2F/AA00150">http://www.some.com/thing/</a>
			<a href="https://sur.ly/o/some.com/thing%2F/AA00150">https://www.some.com/thing/</a>
			';
		
		$this->assertEquals($expected, $surly->process($text));
	}
	
	public function testRemovesUrlFragment()
	{
		$surly = new Surly(null);
		
		$text = '
			<a href="http://www.some.com/thing?test=5&a=5#some$fragmentpart">link</a>
			<a href="https://www.some.com/thing?test=5&a=5#some$fragmentpart">link</a>
			<a href="http://www.some.com/thing/#somefragment">link</a>
			<a href="https://www.some.com/thing/#somefragment">link</a>
			<a href="/thing/#somefragment">link</a>
			';
		
		$expected = '
			<a href="http://sur.ly/some.com/thing%3Ftest%3D5%26a%3D5">link</a>
			<a href="https://sur.ly/some.com/thing%3Ftest%3D5%26a%3D5">link</a>
			<a href="http://sur.ly/some.com/thing%2F">link</a>
			<a href="https://sur.ly/some.com/thing%2F">link</a>
			<a href="/thing/#somefragment">link</a>
			';
		
		$this->assertEquals($expected, $surly->process($text));
	}	
	
	public function testDontReplacesPanelDomains()
	{
		$surly = new Surly(null);
		
		$text = '
			<a href="http://sur.ly/something.com">link</a>
			<a href="https://sur.ly/something.com">link</a>
			<a href="http://surdotly.com/something.com">link</a>
			<a href="https://surdotly.com/something.com">link</a>
			';
		
		$expected = '
			<a href="http://sur.ly/something.com">link</a>
			<a href="https://sur.ly/something.com">link</a>
			<a href="http://surdotly.com/something.com">link</a>
			<a href="https://surdotly.com/something.com">link</a>
			';
		
		$this->assertEquals($expected, $surly->process($text));		
	}
	
	public function testReplaceInvalidUrls()
	{
		$surly = new Surly(null);
		
		$text = '
			<a href="sdfgergerg">link</a>
			<a href="http://www.www.www">link</a>
			<a href="https://www.www.www">link</a>
			<a href="http://www.www.">link</a>
			<a href="https://www.www.">link</a>
			<a href="http://www.">link</a>
			<a href="https://www.">link</a>
			<a href="http://www">link</a>
			<a href="https://www">link</a>
			<a href="http://www-www">link</a>
			<a href="https://www-www">link</a>
			<a href="http://www-www.www">link</a>
			<a href="https://www-www.www">link</a>
			<a href="http://www.www-www.www">link</a>
			<a href="https://www.www-www.www">link</a>
			<a href="http://">link</a>
			<a href="https://">link</a>
			<a href="http://www.www.www">http://www.www.www</a>
			<a href="https://www.www.www">https://www.www.www</a>
			<a href="http://www.www.">http://www.www.</a>
			<a href="https://www.www.">https://www.www.</a>
			<a href="http://www.">http://www.</a>
			<a href="https://www.">https://www.</a>
			<a href="http://www">http://www</a>
			<a href="https://www">https://www</a>
			<a href="http://www-www">http://www-www</a>
			<a href="https://www-www">https://www-www</a>
			<a href="http://www-www.www">http://www-www.www</a>
			<a href="https://www-www.www">https://www-www.www</a>
			<a href="http://www.www-www.www">http://www.www-www.www</a>
			<a href="https://www.www-www.www">https://www.www-www.www</a>
			<a href="http://www.www-www.www/">http://www.www-www.www/</a>
			<a href="https://www.www-www.www/">https://www.www-www.www/</a>
			<a href="http://">http://</a>
			<a href="https://">https://</a>
			';
		
		$expected = '
			<a href="sdfgergerg">link</a>
			<a href="http://sur.ly/www.www">link</a>
			<a href="https://sur.ly/www.www">link</a>
			<a href="http://sur.ly/www.">link</a>
			<a href="https://sur.ly/www.">link</a>
			<a href="http://www.">link</a>
			<a href="https://www.">link</a>
			<a href="http://www">link</a>
			<a href="https://www">link</a>
			<a href="http://www-www">link</a>
			<a href="https://www-www">link</a>
			<a href="http://sur.ly/www-www.www">link</a>
			<a href="https://sur.ly/www-www.www">link</a>
			<a href="http://sur.ly/www-www.www">link</a>
			<a href="https://sur.ly/www-www.www">link</a>
			<a href="http://">link</a>
			<a href="https://">link</a>
			<a href="http://sur.ly/www.www">http://www.www.www</a>
			<a href="https://sur.ly/www.www">https://www.www.www</a>
			<a href="http://sur.ly/www.">http://www.www.</a>
			<a href="https://sur.ly/www.">https://www.www.</a>
			<a href="http://www.">http://www.</a>
			<a href="https://www.">https://www.</a>
			<a href="http://www">http://www</a>
			<a href="https://www">https://www</a>
			<a href="http://www-www">http://www-www</a>
			<a href="https://www-www">https://www-www</a>
			<a href="http://sur.ly/www-www.www">http://www-www.www</a>
			<a href="https://sur.ly/www-www.www">https://www-www.www</a>
			<a href="http://sur.ly/www-www.www">http://www.www-www.www</a>
			<a href="https://sur.ly/www-www.www">https://www.www-www.www</a>
			<a href="http://sur.ly/www-www.www">http://www.www-www.www/</a>
			<a href="https://sur.ly/www-www.www">https://www.www-www.www/</a>
			<a href="http://">http://</a>
			<a href="https://">https://</a>
			';

		$this->assertEquals($expected, $surly->process($text));
	}
	
	public function testReplaceInvalidUrlsWithToolbarId()
	{
		$surly = new Surly('AA00130');
		
		$text = '
			<a href="sdfgergerg">link</a>
			<a href="http://www.www.www">link</a>
			<a href="https://www.www.www">link</a>
			<a href="http://www.www.">link</a>
			<a href="https://www.www.">link</a>
			<a href="http://www.">link</a>
			<a href="https://www.">link</a>
			<a href="http://www">link</a>
			<a href="https://www">link</a>
			<a href="http://www-www">link</a>
			<a href="https://www-www">link</a>
			<a href="http://www-www.www">link</a>
			<a href="https://www-www.www">link</a>
			<a href="http://www.www-www.www">link</a>
			<a href="https://www.www-www.www">link</a>
			<a href="http://">link</a>
			<a href="https://">link</a>
			<a href="http://www.www.www">http://www.www.www</a>
			<a href="https://www.www.www">https://www.www.www</a>
			<a href="http://www.www.">http://www.www.</a>
			<a href="https://www.www.">https://www.www.</a>
			<a href="http://www.">http://www.</a>
			<a href="https://www.">https://www.</a>
			<a href="http://www">http://www</a>
			<a href="https://www">https://www</a>
			<a href="http://www-www">http://www-www</a>
			<a href="https://www-www">https://www-www</a>
			<a href="http://www-www.www">http://www-www.www</a>
			<a href="https://www-www.www">https://www-www.www</a>
			<a href="http://www.www-www.www">http://www.www-www.www</a>
			<a href="https://www.www-www.www">https://www.www-www.www</a>
			<a href="http://www.www-www.www/">http://www.www-www.www/</a>
			<a href="https://www.www-www.www/">https://www.www-www.www/</a>
			<a href="http://">http://</a>
			<a href="https://">https://</a>
			';
		
		$expected = '
			<a href="sdfgergerg">link</a>
			<a href="http://sur.ly/o/www.www/AA00130">link</a>
			<a href="https://sur.ly/o/www.www/AA00130">link</a>
			<a href="http://sur.ly/o/www./AA00130">link</a>
			<a href="https://sur.ly/o/www./AA00130">link</a>
			<a href="http://www.">link</a>
			<a href="https://www.">link</a>
			<a href="http://www">link</a>
			<a href="https://www">link</a>
			<a href="http://www-www">link</a>
			<a href="https://www-www">link</a>
			<a href="http://sur.ly/o/www-www.www/AA00130">link</a>
			<a href="https://sur.ly/o/www-www.www/AA00130">link</a>
			<a href="http://sur.ly/o/www-www.www/AA00130">link</a>
			<a href="https://sur.ly/o/www-www.www/AA00130">link</a>
			<a href="http://">link</a>
			<a href="https://">link</a>
			<a href="http://sur.ly/o/www.www/AA00130">http://www.www.www</a>
			<a href="https://sur.ly/o/www.www/AA00130">https://www.www.www</a>
			<a href="http://sur.ly/o/www./AA00130">http://www.www.</a>
			<a href="https://sur.ly/o/www./AA00130">https://www.www.</a>
			<a href="http://www.">http://www.</a>
			<a href="https://www.">https://www.</a>
			<a href="http://www">http://www</a>
			<a href="https://www">https://www</a>
			<a href="http://www-www">http://www-www</a>
			<a href="https://www-www">https://www-www</a>
			<a href="http://sur.ly/o/www-www.www/AA00130">http://www-www.www</a>
			<a href="https://sur.ly/o/www-www.www/AA00130">https://www-www.www</a>
			<a href="http://sur.ly/o/www-www.www/AA00130">http://www.www-www.www</a>
			<a href="https://sur.ly/o/www-www.www/AA00130">https://www.www-www.www</a>
			<a href="http://sur.ly/o/www-www.www/AA00130">http://www.www-www.www/</a>
			<a href="https://sur.ly/o/www-www.www/AA00130">https://www.www-www.www/</a>
			<a href="http://">http://</a>
			<a href="https://">https://</a>
			';
		
		$this->assertEquals($expected, $surly->process($text));
	}

	public function testDontReplaceRelativeLinks()
	{
		$surly = new Surly(null);
		
		$text = '
			<a href="/somepage">link</a>
			<a href="/index.php?q=node/3">link</a>
			';
		
		$this->assertEquals($text, $surly->process($text));
	}
	
	public function testDomainWhitelist()
	{
		$surly = new Surly(null);
		$surly->whitelist('lE.com');
		
		$text = '
			<a href="http://le.com">link</a>
			<a href="https://le.com">link</a>
			<a href="http://le.com#something">link</a>
			<a href="https://le.com#something">link</a>
			<a href="http://lE.cOm">link</a>
			<a href="https://lE.cOm">link</a>
			<a href="http://sub.le.com">link</a>
			<a href="https://sub.le.com">link</a>
			<a href="http://www.le.com">link</a>
			<a href="https://www.le.com">link</a>
			<a href="http://le.com/something">link</a>
			<a href="https://le.com/something">link</a>
			<a href="http://www.le.com/something">link</a>
			<a href="https://www.le.com/something">link</a>
			<a href="http://www.google.com/something">link</a>
			<a href="https://www.google.com/something">link</a>
			<a href="http://google.com/something">link</a>
			<a href="https://google.com/something">link</a>
			<a href="http://www.google.com">link</a>
			<a href="https://www.google.com">link</a>
			<a href="http://google.com">link</a>
			<a href="https://google.com">link</a>
			';
		
		$expected = '
			<a href="http://le.com">link</a>
			<a href="https://le.com">link</a>
			<a href="http://le.com#something">link</a>
			<a href="https://le.com#something">link</a>
			<a href="http://lE.cOm">link</a>
			<a href="https://lE.cOm">link</a>
			<a href="http://sub.le.com">link</a>
			<a href="https://sub.le.com">link</a>
			<a href="http://www.le.com">link</a>
			<a href="https://www.le.com">link</a>
			<a href="http://le.com/something">link</a>
			<a href="https://le.com/something">link</a>
			<a href="http://www.le.com/something">link</a>
			<a href="https://www.le.com/something">link</a>
			<a href="http://sur.ly/google.com/something">link</a>
			<a href="https://sur.ly/google.com/something">link</a>
			<a href="http://sur.ly/google.com/something">link</a>
			<a href="https://sur.ly/google.com/something">link</a>
			<a href="http://sur.ly/google.com">link</a>
			<a href="https://sur.ly/google.com">link</a>
			<a href="http://sur.ly/google.com">link</a>
			<a href="https://sur.ly/google.com">link</a>
			';
		
		$this->assertEquals($expected, $surly->process($text));		
		
		$surly = new Surly(null);
		$surly->whitelist('www.le.com');
		$this->assertEquals($expected, $surly->process($text));
	}
	
	public function testDomainWhitelistWithHttp()
	{
		$surly = new Surly(null);
		$surly->whitelist('http://test.com');
		
		$text = '<a href="http://test.com">test</a>';
		$expected = '<a href="http://test.com">test</a>';
		
		$this->assertEquals($expected, $surly->process($text));
	}
	
	public function testDomainWhitelistWithHttps()
	{
		$surly = new Surly(null);
		$surly->whitelist('http://test.com');
		
		$text = '<a href="https://test.com">test</a>';
		$expected = '<a href="https://test.com">test</a>';
		
		$this->assertEquals($expected, $surly->process($text));
	}

	public function testProcessUrl()
	{
		$url2expected = array(
			'https://www.cnn.com' => 'https://sur.ly/cnn.com',
			'https://cnn.com' => 'https://sur.ly/cnn.com',
			'http://www.cnn.com' => 'http://sur.ly/cnn.com',
			'http://cnn.com' => 'http://sur.ly/cnn.com',

			'https://www.cnn.com/' => 'https://sur.ly/cnn.com',
			'https://cnn.com/' => 'https://sur.ly/cnn.com',
			'http://www.cnn.com/' => 'http://sur.ly/cnn.com',
			'http://cnn.com/' => 'http://sur.ly/cnn.com',

			'https://www.cnn.com/new?ffd' => 'https://sur.ly/cnn.com/new%3Fffd',
			'https://cnn.com/new?ffd' => 'https://sur.ly/cnn.com/new%3Fffd',
			'http://www.cnn.com/new?ffd' => 'http://sur.ly/cnn.com/new%3Fffd',
			'http://cnn.com/new?ffd' => 'http://sur.ly/cnn.com/new%3Fffd',

			'https://www.cnn.com/new/ss?ffd' => 'https://sur.ly/cnn.com/new%2Fss%3Fffd',
			'https://cnn.com/new/ss?ffd' => 'https://sur.ly/cnn.com/new%2Fss%3Fffd',
			'http://www.cnn.com/new/ss?ffd' => 'http://sur.ly/cnn.com/new%2Fss%3Fffd',
			'http://cnn.com/new/ss?ffd' => 'http://sur.ly/cnn.com/new%2Fss%3Fffd',

			'http://www.' => 'http://www.',
			'https://www.' => 'https://www.',
			'http://www-www' => 'http://www-www',
			'https://www-www' => 'https://www-www',
			'http://www-www.www' => 'http://sur.ly/www-www.www',
			'https://www-www.www' => 'https://sur.ly/www-www.www',
			'http://www.www-www.www' => 'http://sur.ly/www-www.www',
			'https://www.www-www.www' => 'https://sur.ly/www-www.www',
			'http://www' => 'http://www',
			'https://www' => 'https://www',
			
			'http://www1.cnn.com' => 'http://sur.ly/www1.cnn.com',
			'https://www1.cnn.com' => 'https://sur.ly/www1.cnn.com',

			'cnn.com' => 'cnn.com',
			'www.cnn.com' => 'www.cnn.com',
		);
		$surly = new Surly(null);
		foreach ($url2expected as $url => $encodedUrl) {
			$this->assertEquals($encodedUrl, $surly->processUrl($url));
		}
	}

	public function testProcessUrlToolbarId()
	{
		$url2expected = array(
			'https://www.cnn.com' => 'https://sur.ly/o/cnn.com/AA000150',
			'https://cnn.com' => 'https://sur.ly/o/cnn.com/AA000150',
			'http://www.cnn.com' => 'http://sur.ly/o/cnn.com/AA000150',
			'http://cnn.com' => 'http://sur.ly/o/cnn.com/AA000150',

			'https://www.cnn.com/' => 'https://sur.ly/o/cnn.com/AA000150',
			'https://cnn.com/' => 'https://sur.ly/o/cnn.com/AA000150',
			'http://www.cnn.com/' => 'http://sur.ly/o/cnn.com/AA000150',
			'http://cnn.com/' => 'http://sur.ly/o/cnn.com/AA000150',

			'https://www.cnn.com/new?ffd' => 'https://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'https://cnn.com/new?ffd' => 'https://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'http://www.cnn.com/new?ffd' => 'http://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'http://cnn.com/new?ffd' => 'http://sur.ly/o/cnn.com/new%3Fffd/AA000150',

			'https://www.cnn.com/new/ss?ffd' => 'https://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'https://cnn.com/new/ss?ffd' => 'https://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'http://www.cnn.com/new/ss?ffd' => 'http://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'http://cnn.com/new/ss?ffd' => 'http://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',

			'http://www.' => 'http://www.',
			'https://www.' => 'https://www.',
			'http://www-www' => 'http://www-www',
			'https://www-www' => 'https://www-www',
			'http://www-www.www' => 'http://sur.ly/o/www-www.www/AA000150',
			'https://www-www.www' => 'https://sur.ly/o/www-www.www/AA000150',
			'http://www.www-www.www' => 'http://sur.ly/o/www-www.www/AA000150',
			'https://www.www-www.www' => 'https://sur.ly/o/www-www.www/AA000150',
			'http://www' => 'http://www',
			'https://www' => 'https://www',

			'cnn.com' => 'cnn.com',
			'www.cnn.com' => 'www.cnn.com',
		);
		$surly = new Surly('AA000150');
		foreach ($url2expected as $url => $encodedUrl) {
			$this->assertEquals($encodedUrl, $surly->processUrl($url));
		}
	}

	public function testProcessMultipleUrls()
	{
		$url2expected = array(
			'https://www.cnn.com' => 'https://sur.ly/cnn.com',
			'https://cnn.com' => 'https://sur.ly/cnn.com',
			'http://www.cnn.com' => 'http://sur.ly/cnn.com',
			'http://cnn.com' => 'http://sur.ly/cnn.com',

			'https://www.cnn.com/' => 'https://sur.ly/cnn.com',
			'https://cnn.com/' => 'https://sur.ly/cnn.com',
			'http://www.cnn.com/' => 'http://sur.ly/cnn.com',
			'http://cnn.com/' => 'http://sur.ly/cnn.com',

			'https://www.cnn.com/new?ffd' => 'https://sur.ly/cnn.com/new%3Fffd',
			'https://cnn.com/new?ffd' => 'https://sur.ly/cnn.com/new%3Fffd',
			'http://www.cnn.com/new?ffd' => 'http://sur.ly/cnn.com/new%3Fffd',
			'http://cnn.com/new?ffd' => 'http://sur.ly/cnn.com/new%3Fffd',

			'https://www.cnn.com/new/ss?ffd' => 'https://sur.ly/cnn.com/new%2Fss%3Fffd',
			'https://cnn.com/new/ss?ffd' => 'https://sur.ly/cnn.com/new%2Fss%3Fffd',
			'http://www.cnn.com/new/ss?ffd' => 'http://sur.ly/cnn.com/new%2Fss%3Fffd',
			'http://cnn.com/new/ss?ffd' => 'http://sur.ly/cnn.com/new%2Fss%3Fffd',

			'http://www.' => 'http://www.',
			'https://www.' => 'https://www.',
			'http://www-www' => 'http://www-www',
			'https://www-www' => 'https://www-www',
			'http://www-www.www' => 'http://sur.ly/www-www.www',
			'https://www-www.www' => 'https://sur.ly/www-www.www',
			'http://www.www-www.www' => 'http://sur.ly/www-www.www',
			'https://www.www-www.www' => 'https://sur.ly/www-www.www',
			'http://www' => 'http://www',
			'https://www' => 'https://www',

			'cnn.com' => 'cnn.com',
			'www.cnn.com' => 'www.cnn.com',
		);
		$surly = new Surly(null);
		foreach ($url2expected as $url => $encodedUrl) {
			$this->assertEquals(array($encodedUrl), $surly->processMultipleUrls(array($url)));
		}
	}

	public function testProcessMultipleUrlsToolbarId()
	{
		$url2expected = array(
			'https://www.cnn.com' => 'https://sur.ly/o/cnn.com/AA000150',
			'https://cnn.com' => 'https://sur.ly/o/cnn.com/AA000150',
			'http://www.cnn.com' => 'http://sur.ly/o/cnn.com/AA000150',
			'http://cnn.com' => 'http://sur.ly/o/cnn.com/AA000150',

			'https://www.cnn.com/' => 'https://sur.ly/o/cnn.com/AA000150',
			'https://cnn.com/' => 'https://sur.ly/o/cnn.com/AA000150',
			'http://www.cnn.com/' => 'http://sur.ly/o/cnn.com/AA000150',
			'http://cnn.com/' => 'http://sur.ly/o/cnn.com/AA000150',

			'https://www.cnn.com/new?ffd' => 'https://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'https://cnn.com/new?ffd' => 'https://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'http://www.cnn.com/new?ffd' => 'http://sur.ly/o/cnn.com/new%3Fffd/AA000150',
			'http://cnn.com/new?ffd' => 'http://sur.ly/o/cnn.com/new%3Fffd/AA000150',

			'https://www.cnn.com/new/ss?ffd' => 'https://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'https://cnn.com/new/ss?ffd' => 'https://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'http://www.cnn.com/new/ss?ffd' => 'http://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',
			'http://cnn.com/new/ss?ffd' => 'http://sur.ly/o/cnn.com/new%2Fss%3Fffd/AA000150',

			'http://www.' => 'http://www.',
			'https://www.' => 'https://www.',
			'http://www-www' => 'http://www-www',
			'https://www-www' => 'https://www-www',
			'http://www-www.www' => 'http://sur.ly/o/www-www.www/AA000150',
			'https://www-www.www' => 'https://sur.ly/o/www-www.www/AA000150',
			'http://www.www-www.www' => 'http://sur.ly/o/www-www.www/AA000150',
			'https://www.www-www.www' => 'https://sur.ly/o/www-www.www/AA000150',
			'http://www' => 'http://www',
			'https://www' => 'https://www',

			'cnn.com' => 'cnn.com',
			'www.cnn.com' => 'www.cnn.com',
		);
		$surly = new Surly('AA000150');
		foreach ($url2expected as $url => $encodedUrl) {
			$this->assertEquals(array($encodedUrl), $surly->processMultipleUrls(array($url)));
		}
	}

	public function testUrlEncode()
	{
		$url2EncodedUrl = array(
			'https://www.cnn.com' => 'cnn.com',
			'https://cnn.com' => 'cnn.com',
			'http://www.cnn.com' => 'cnn.com',
			'http://cnn.com' => 'cnn.com',
			'www.cnn.com' => 'cnn.com',
			'cnn.com' => 'cnn.com',

			'https://www.cnn.com/' => 'cnn.com',
			'https://cnn.com/' => 'cnn.com',
			'http://www.cnn.com/' => 'cnn.com',
			'http://cnn.com/' => 'cnn.com',
			'www.cnn.com/' => 'cnn.com',
			'cnn.com/' => 'cnn.com',

			'https://www.cnn.com/new?ffd' => 'cnn.com/new%3Fffd',
			'https://cnn.com/new?ffd' => 'cnn.com/new%3Fffd',
			'http://www.cnn.com/new?ffd' => 'cnn.com/new%3Fffd',
			'http://cnn.com/new?ffd' => 'cnn.com/new%3Fffd',
			'www.cnn.com/new?ffd' => 'cnn.com/new%3Fffd',
			'cnn.com/new?ffd' => 'cnn.com/new%3Fffd',

			'https://www.cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',
			'https://cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',
			'http://www.cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',
			'http://cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',
			'www.cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',
			'cnn.com/new/ss?ffd' => 'cnn.com/new%2Fss%3Fffd',

			'//////' => '%2F%2F%2F%2F%2F%2F',
			'http://www.' => 'www.',
			'https://www.' => 'www.',
		);
		$surly = new Surly(null);

		foreach ($url2EncodedUrl as $url => $encodedUrl) {
			$this->assertEquals($encodedUrl, $surly->_urlEncode($url));
		}
	}
}